@@ -22,7 +22,7 @@ from typing import Iterable
 if sys.version_info.major >= 3 and sys.version_info.minor >= 8:
     from typing import Protocol
 else:
-    from typing_extensions import Protocol
+    Protocol = object
 
 
 class I2CBusSpeed(IntEnum):
