@@ -13,7 +13,7 @@
 The :mod:`pumpkin_supmcu.supmcu` module contains the parsing, communication interface and module telemetry enumeration
 definitions.
 """
-from .discovery import request_telemetry_definition, request_module_definition, get_values, set_values
+from .discovery import request_telemetry_definition, request_module_definition, get_values, set_values, get_version_string
 from .i2c import SupMCUMaster
 from .parsing import parse_telemetry, parse_header, DataItemParser, Parsers
 from .types import SupMCUModuleDefinition, SupMCUTelemetryDefinition, typeof_supmcu_fmt_char, DataType, \
