@@ -19,18 +19,21 @@ from typing import Union, Optional, List, Any
 
 from .i2c import SupMCUMaster
 from .serial import SupMCUSerialMaster
-from .parsing import parse_telemetry, _format_to_length
+from .parsing import parse_telemetry, _format_to_length, parse_command
 from .types import SupMCUTelemetryDefinition, SupMCUModuleDefinition, TelemetryType, \
-    _supmcu_fmt_data_type, _data_type_sizes, TelemetryDataItem
+    _supmcu_fmt_data_type, _data_type_sizes, TelemetryDataItem, SupMCUCommand
 from ..i2c import I2CMaster
 
 SIZEOF_HEADER_FOOTER = 13
+SIZEOF_COMMAND_DATA = 33
 SUPMCU_VERSION_DEFINITION = SupMCUTelemetryDefinition("Firmware Version", 77, 0, "S")
 SUPMCU_LENGTH_DEFINITION = SupMCUTelemetryDefinition("Length", 2 + SIZEOF_HEADER_FOOTER, 0, "s")
 SUPMCU_NAME_DEFINITION = SupMCUTelemetryDefinition("Name", 33 + SIZEOF_HEADER_FOOTER, 0, "S")
 SUPMCU_FORMAT_DEFINITION = SupMCUTelemetryDefinition("Format", 25 + SIZEOF_HEADER_FOOTER, 0, "S")
 SUPMCU_TELEMETRY_AMOUNT_DEFINITION = SupMCUTelemetryDefinition("Amount", 4 + SIZEOF_HEADER_FOOTER, 14, "s,s")
+SUPMCU_COMMANDS_AMOUNT_DEFINITION = SupMCUTelemetryDefinition("Commands", 2 + SIZEOF_HEADER_FOOTER, 17, "s")
 SUPMCU_TELEMETRY_AMOUNT_STR = "SUP:TEL? 14\n"
+SUPMCU_COMMAND_AMOUNT_STR = "SUP:TEL? 17\n"
 _DEFAULT_RESPONSE_DELAY = 0.1  # 100 ms between I2C Write and Read
 
 
@@ -268,4 +271,61 @@ def request_module_definition(i2c_master: Union[I2CMaster, SupMCUMaster],
     module_defs = {}
     for idx in range(module_amount):
         module_defs[idx] = request_telemetry_definition(i2c_master, address, module_cmd_name, idx, response_delay, is_simulatable_mod)
-    return SupMCUModuleDefinition(module_name, module_cmd_name, address, supmcu_defs, module_defs)
+        
+    # Grab the amount of commands on the module, then start requesting ALL command names.
+    amount_cmd_resp = _write_read_supcmu_i2c(i2c_master,
+                                             address,
+                                             SUPMCU_COMMAND_AMOUNT_STR,
+                                             SUPMCU_COMMANDS_AMOUNT_DEFINITION.telemetry_length,
+                                             response_delay)
+    amount_commands = parse_telemetry(amount_cmd_resp, SUPMCU_COMMANDS_AMOUNT_DEFINITION)
+    commands_amount = amount_commands.items[0].value
+
+    command_defs = {}
+    for idx in range(commands_amount):
+        command_defs[idx] = request_command_name(i2c_master, address, 'SUP', idx, response_delay)
+
+    return SupMCUModuleDefinition(module_name, module_cmd_name, address, supmcu_defs, module_defs, command_defs)
+
+
+def request_command_name(i2c_master: Union[I2CMaster, SupMCUMaster],
+                         address: int,
+                         module_cmd_name: str,
+                         idx: int,
+                         response_delay: Optional[float] = None) -> SupMCUCommand:
+    """
+    Requests the command information from the device at I2C address `address`, using the module
+    short name `module_cmd_name` (e.g. BM for Battery Module), concatenating that with `idx` of the command
+    s.t. cmd_to_send is `<module_cmd_name>:COM? <idx>,NAME (format is always S, length is fixed).`
+
+    :param i2c_master: The I2CMaster device to use.
+    :param address: The address of the device to request information from.
+    :param module_cmd_name: The module name used in the context of SCPI commands (e.g. DCPS for Desktop CubeSat Power
+                            Supply).
+    :param idx: The command index to get the name of.
+    :param response_delay: The amount of time in seconds to wait between I2C Write and read. Can be None, or set
+                            from SupMCUMaster passed in as `i2c_master`.
+    :return: a SupMCUCommand.
+    """
+    if isinstance(i2c_master, SupMCUMaster):
+        if response_delay is None:
+            response_delay = i2c_master.request_delay
+        i2c_master = i2c_master.i2c_master
+    if response_delay is None:
+        # None was set by the SupMCU master or the passed in variable.
+        response_delay = _DEFAULT_RESPONSE_DELAY
+
+    # Find out length and name information
+    name_bytes = _write_read_supcmu_i2c(i2c_master, address, f'{module_cmd_name}:COM? {idx}\n',
+                                        SIZEOF_HEADER_FOOTER + SIZEOF_COMMAND_DATA, response_delay)
+
+    # Parse the response bytes as a command name, then check to see if it is ready
+    name_response = parse_command(name_bytes)
+
+    # Raise exception if any of the responses are flagged as not ready.
+    if not name_response.header.ready:
+        raise RuntimeError(
+            f'`{module_cmd_name}:COM? {idx}` returned a non-ready response. Try increasing `response_delay`.')
+
+    return SupMCUCommand(name_response.command_name, idx)
+
