@@ -21,7 +21,7 @@ from abc import abstractmethod
 from typing import Tuple, Callable, List, Dict, Union, Any
 
 from .types import TelemetryDataItem, SupMCUHDR, SupMCUTelemetry, SupMCUTelemetryDefinition, DataType, \
-    sizeof_supmcu_type, typeof_supmcu_fmt_char
+    sizeof_supmcu_type, typeof_supmcu_fmt_char, SupMCUCommandResponse, SupMCUCommand
 
 if sys.version_info.major >= 3 and sys.version_info.minor >= 8:
     from typing import Protocol
@@ -205,3 +205,19 @@ def parse_telemetry(b: bytes, supmcu_telemetry_def: Union[str, SupMCUTelemetryDe
             pass
 
     return SupMCUTelemetry(header, items)
+
+
+def parse_command(b: bytes) -> SupMCUCommandResponse:
+    """
+    Parses the bytes `b` into a SupMCUCommandResponse.
+
+    :param b: The command query response bytes to parse.
+    :return: A SupMCUCommandResponse.
+    """
+
+    # Parse the SupMCU header
+    header, b = parse_header(b)
+
+    # parse the command name
+    name, _ = Parsers['S'].parse(b)
+    return SupMCUCommandResponse(header, name.string_value)
