@@ -14,7 +14,7 @@ These data types are used throughout the :mod:`pumpkin_supmcu.supmcu` to type an
 """
 from enum import IntEnum
 from typing import Dict, Any, List, Optional
-from dataclasses import dataclass
+from dataclasses import dataclass, field
 
 
 class DataType(IntEnum):
@@ -124,14 +124,23 @@ class SupMCUTelemetryDefinition(object):
     defaults: Optional[Any] = None
 
 
+@dataclass
+class SupMCUCommand:
+    """A SupMCU Command consists of only a name and an index"""
+    name: str
+    idx: int
+
+
 @dataclass
 class SupMCUModuleDefinition(object):
-    """A SupMCU Module definition consists of the name, address, cmd_name, SupMCU Telemetry and module telemetry."""
+    """A SupMCU Module definition consists of the name, address, cmd_name, SupMCU Telemetry, module telemetry, and
+    SupMCU commands and module commands."""
     name: str
     cmd_name: str
     address: int
     supmcu_telemetry: Dict[int, SupMCUTelemetryDefinition]
     module_telemetry: Dict[int, SupMCUTelemetryDefinition]
+    commands: Dict[int, SupMCUCommand] = field(default_factory=dict)
 
 
 @dataclass
@@ -160,6 +169,13 @@ class SupMCUTelemetry(object):
     items: List[TelemetryDataItem]
 
 
+@dataclass
+class SupMCUCommandResponse(object):
+    """A SupMCU Command request response. Consists of a header and string representing the command name."""
+    header: SupMCUHDR
+    command_name: str
+
+
 def sizeof_supmcu_type(t: DataType) -> int:
     """
     Returns the size in bytes of a SupMCU Data type.
